@@ -2,16 +2,18 @@ import re
 import inspect
 import tempfile
 import pipes
+import gi
+import os
 
 class print_dialog:
     def destroy(self):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         self.print_get_widget(self.name).destroy()
 
     def saveSettings(self):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         w = self.print_get_widget("printPageRadioButton")
         if w:
             self.gui.settings.set_boolean("print-page", w.get_active())
@@ -32,28 +34,28 @@ class print_dialog:
         w = self.print_get_widget("printCommandEntry")
         if w:
             self.gui.settings.set_string("print-command", w.get_text())
-        
+
         return
-    
+
     def on_printDialog_destroy(self, widget):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         return
-    
+
     def on_printCommandEntry_key_press_event(self, widget, key_event):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2], vars()
+            print(inspect.getframeinfo(inspect.currentframe())[2], vars())
 
-        # to get all keysyms: print Gdk.KEY___dict__
-        if key_event.keyval == Gdk.KEY_Return or key_event.keyval == Gdk.KEY_KP_Enter:
+        # to get all keysyms see gdk/gdkkeysyms.h
+        if key_event.keyval == gi.repository.Gdk.KEY_Return or key_event.keyval == gi.repository.Gdk.KEY_KP_Enter:
             self.on_printOKButton_clicked(widget)
-        if key_event.keyval == Gdk.KEY_Escape:
+        if key_event.keyval == gi.repository.Gdk.KEY_Escape:
             self.on_printCancelButton_clicked(widget)
         return
 
     def _get_settings(self):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         print_page = print_selection = print_all = page_feed = bold_titles = 0
         print_command = ""
         w = self.print_get_widget("printPageRadioButton")
@@ -76,9 +78,9 @@ class print_dialog:
         w = self.print_get_widget("printCommandEntry")
         if w:
             print_command = w.get_text()
-        
+
         return print_page, print_selection, print_all, page_feed, bold_titles, print_command
-        
+
     def on_printOKButton_clicked(self, widget):
         """
         if print_all is set then
@@ -92,9 +94,9 @@ class print_dialog:
                 else
                     print all the selected pages.
         """
-        
+
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         self.gui.sync_text_buffer()
         self.saveSettings()
         print_page, print_selection, print_all, page_feed, bold_titles, print_command = self._get_settings()
@@ -103,11 +105,11 @@ class print_dialog:
             this_iter = self.gui.get_root()
         else:
             this_iter = self.gui.get_first_selected_iter()
-            
+
         if not this_iter:
             self.gui.msg(_("Nothing selected"))
             return
-        
+
         last_selected = self.gui.get_last_selected_iter()
         if not last_selected:
             self.gui.msg(_("Nothing selected"))
@@ -115,7 +117,7 @@ class print_dialog:
 
         t = pipes.Template()
         t.append(print_command, "-.")
-        scratch = tempfile.mktemp()
+        scratch = tempfile.mkstemp(text = True)[1]
         f = t.open(scratch, "w")
 
         single_page = 0
@@ -142,13 +144,13 @@ class print_dialog:
         os.unlink(scratch)
         self.destroy()
         return
-        
+
     def on_printCancelButton_clicked(self, widget):
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
         self.destroy()
         return
-    
+
     def __init__(self, gui):
         """
         Print dialog
@@ -156,7 +158,7 @@ class print_dialog:
 
         self.gui = gui
         if self.gui.debug:
-            print inspect.getframeinfo(inspect.currentframe())[2]
+            print(inspect.getframeinfo(inspect.currentframe())[2])
 
         callbacks = {
             "on_printDialog_destroy":                   self.on_printDialog_destroy,
@@ -190,12 +192,12 @@ class print_dialog:
         if w:
             w.set_text(self.gui.settings.get_string("print-command"))
         return
-        
+
 # print_dialog
 
 # Local variables:
 # eval:(setq compile-command "cd ..; ./gjots2 test.gjots")
-# eval:(setq indent-tabs-mode 1)
+# eval:(setq indent-tabs-mode nil)
 # eval:(setq tab-width 4)
 # eval:(setq python-indent 4)
 # End:
